@@ -4,10 +4,11 @@
 #' `rename_fude()` renames the 6-digit local government code of the list
 #' returned by [read_fude()] to the corresponding Japanese name in order to
 #' make the data human-friendly.
+#'
 #' @param data
-#'   List of [sf::sf()] objects.
+#'   Fude Polygon data as returned by [read_fude()].
 #' @param suffix
-#'   logical. If `FALSE`, suffixes such as "SHI" and "KU" in local government
+#'   Logical. If `FALSE`, suffixes such as "-SHI" and "-KU" in local government
 #'   names are removed.
 #' @param romaji
 #'   If not `NULL`, rename the local government name in romaji instead of
@@ -16,22 +17,28 @@
 #'   - `"lower"`: Lower case.
 #'   - `"upper"`: Upper case.
 #' @param quiet
-#'   logical. Suppress information about the data to be read.
-#' @returns A list of [sf::sf()] objects.
+#'   Logical. Suppress information about the data to be read.
+#'
+#' @returns
+#'   A list of [sf::sf()] objects.
+#'
 #' @seealso [read_fude()].
 #'
 #' @examples
 #' path <- system.file("extdata", "castle.zip", package = "fude")
-#' d <- read_fude(path, stringsAsFactors = FALSE, quiet = FALSE)
+#' d <- read_fude(path, quiet = FALSE)
 #' d2 <- rename_fude(d)
 #' d2 <- rename_fude(d, suffix = FALSE)
 #' d2 <- d |> rename_fude(romaji = "upper")
 #'
 #' @export
-rename_fude <- function(data,
-                        suffix = TRUE,
-                        romaji = NULL,
-                        quiet = TRUE) {
+rename_fude <- function(
+  data,
+  suffix = TRUE,
+  romaji = NULL,
+  quiet = TRUE
+) {
+  validate_fude(data)
 
   old_names <- names(data)
   nen <- sub("(_.*)", "_", old_names)
@@ -41,7 +48,7 @@ rename_fude <- function(data,
   new_names <- get_lg_name(matching_codes, romaji)
 
   if (isFALSE(suffix)) {
-    new_names <- gsub("-SHI|-KU|-CHO|-MACHI|-SON|-MURA", "", new_names, ignore.case = TRUE)
+    new_names <- remove_romaji_suffix(new_names)
     new_names <- sub("\u5e02(.*)(\u533a$)", "_\\1", new_names)
     new_names <- sub("(\u5e02|\u533a|\u753a|\u6751)$", "", new_names)
   }
@@ -60,7 +67,10 @@ rename_fude <- function(data,
   return(x)
 }
 
-get_lg_name <- function(matching_codes, romaji = NULL) {
+get_lg_name <- function(
+  matching_codes,
+  romaji = NULL
+) {
   matching_idx <- match(matching_codes, fude::lg_code_table$lg_code)
 
   if (is.null(romaji)) {
@@ -72,14 +82,12 @@ get_lg_name <- function(matching_codes, romaji = NULL) {
       x <- tolower(x)
     } else {
       if (romaji == "title") {
-
         unique_string <- "uniquestring"
         tmp <- gsub("-", unique_string, x)
         tmp <- sub("_", " ", tmp)
         x <- tools::toTitleCase(tolower(tmp))
         x <- gsub(unique_string, "-", x)
         x <- sub(" ", "_", x)
-
       }
     }
   }
